@@ -120,7 +120,7 @@ def _tar_xf_no_libarchive(tarball_full_path, destination_directory=None):
                     )
                 else:
                     raise InvalidArchiveError(tarball_full_path,
-                                              "failed with error: {}" % str(e))
+                                              "failed with error: {}".format(str(e)))
 
     if sys.platform.startswith('linux') and os.getuid() == 0:
         # When extracting as root, tarfile will by restore ownership
@@ -166,9 +166,5 @@ class CondaTarBZ2(AbstractBaseFormat):
     def get_pkg_details(in_file):
         stat_result = os.stat(in_file)
         size = stat_result.st_size
-        # open the file twice because we need to start from the beginning each time
-        with open(in_file, 'rb') as f:
-            md5 = utils.md5_checksum(f)
-        with open(in_file, 'rb') as f:
-            sha256 = utils.sha256_checksum(f)
+        md5, sha256 = utils.checksums(in_file, ('md5', 'sha256'))
         return {"size": size, "md5": md5, "sha256": sha256}
